@@ -64,6 +64,7 @@ class Banners extends CGExtensions
    ---------------------------------------------------------*/
   protected function _testip($range,$ip) 
   {
+    if( !$range || !$ip ) return 0; 
     $result = 1;
 
 # IP Pattern Matcher
@@ -145,22 +146,13 @@ class Banners extends CGExtensions
    ---------------------------------------------------------*/
   public function MinimumCMSVersion()
   {
-    return '1.9.2';
+    return '1.10.2';
   }
 
 
-  /*---------------------------------------------------------
-   GetVersion()
-   This can return any string, preferably a number or
-   something that makes sense for designating a version.
-   The CMS will use this to identify whether or not
-   the installed version of the module is current, and
-   the module will use it to figure out how to upgrade
-   itself if requested.	   
-   ---------------------------------------------------------*/
   public function GetVersion()
   {
-    return '2.5.1';
+    return '2.5.3';
   }
 
 
@@ -169,7 +161,7 @@ class Banners extends CGExtensions
    ---------------------------------------------------------*/
   public function GetHelp()
   {
-    return $this->Lang('help');
+    return @file_get_contents(dirname(__FILE__).'/help.inc');
   }
 
 
@@ -189,6 +181,10 @@ class Banners extends CGExtensions
   }
 
 
+  public function LazyLoadAdmin() {
+    return TRUE;
+  }
+
   /*---------------------------------------------------------
    GetAuthor()
    ---------------------------------------------------------*/
@@ -309,12 +305,13 @@ class Banners extends CGExtensions
     $this->CreateParameter('name','',$this->Lang('help_param_name'));
 
     // routes
+    $returnid = cmsms()->GetContentOperations()->GetDefaultContent();
     $this->RegisterRoute('/banner\/byname\/(?P<name>.*)$/',
-			 array('action'=>'default','showtemplate'=>'false'));
+			 array('action'=>'default','showtemplate'=>'false','returnid'=>$returnid));
     $this->RegisterRoute('/banner\/random\/(?P<category>.*)$/',
-			 array('action'=>'default','showtemplate'=>'false'));
+			 array('action'=>'default','showtemplate'=>'false','returnid'=>$returnid));
     $this->RegisterRoute('/banner\/sequential\/(?P<category>.*)$/',
-			 array('action'=>'default','mode'=>'sequential','showtemplate'=>'false'));
+			 array('action'=>'default','mode'=>'sequential','showtemplate'=>'false','returnid'=>$returnid));
   }
 
 
@@ -325,7 +322,7 @@ class Banners extends CGExtensions
   protected function _DisplayErrorPage($id, &$params, $returnid, $message='')
   {
     global $gCms;
-    $smarty =& $gCms->GetSmarty();
+    $smarty = $gCms->GetSmarty();
     $smarty->assign('title_error', $this->Lang('error'));
     if ($message != '')
       {
@@ -345,7 +342,7 @@ class Banners extends CGExtensions
    ---------------------------------------------------------*/
   protected function &_getUploadsModule()
   {
-    $module =& $this->getModuleInstance("Uploads");
+    $module = $this->getModuleInstance("Uploads");
     if( $module )
       {
 	$ver = $module->GetVersion();
