@@ -99,7 +99,7 @@ if( $exclude == 0 )
 
     $now = $db->DbTimeStamp(time());
     $from = "SELECT * FROM ".cms_db_prefix()."module_banners WHERE (category_id = \"$category_id\") AND";
-    $where .= "(start_date <= $now) AND (expires > $now or isnull(expires)) AND (max_impressions = 0 OR num_impressions < max_impressions)";
+    $where = "(start_date <= $now) AND (expires > $now or isnull(expires)) AND (max_impressions = 0 OR num_impressions < max_impressions)";
     $order = "ORDER BY RAND()";
     $limit = "LIMIT 0,1";
 
