@@ -40,7 +40,7 @@ if (!$this->CheckPermission ('Manage Banners'))
     return;
   }
 
-    $db =& $this->GetDb();
+    $db = $this->GetDb();
     $smarty->assign ('title', $this->Lang ('editcategory'));
 
     // check things out
@@ -97,7 +97,7 @@ $smarty->assign('prompt_template',$this->Lang('template'));
 $smarty->assign('input_template',
 		$this->CreateSyntaxArea($id,$row['template'],'input_template'));
 
-    $uploads =& $this->_getUploadsModule();
+    $uploads = $this->_getUploadsModule();
     if( $uploads )
       {
 	$categorylist = $uploads->getCategoryList();
