@@ -48,7 +48,7 @@ if( isset($params['submitcategory']) )
   }
   
 // get a category list for the filter
-$db =& $this->GetDb();
+$db = $this->GetDb();
 $categorylist = array();
 $query = "SELECT * FROM ".cms_db_prefix()."module_banners_categories
           ORDER BY name ASC";
