@@ -35,7 +35,7 @@
 #-------------------------------------------------------------------------
 #END_LICENSE
 
-$db =& $this->GetDb();
+$db = $this->GetDb();
 $dict = NewDataDictionary($db);
 
     $current_version = $oldversion;
